telepathy-qt: dbus-tubes: Fix warning and comment

Dario Freddi drf at kemper.freedesktop.org
Tue Jul 3 15:08:59 PDT 2012


Module: telepathy-qt
Branch: master
Commit: 6eafc3bf22b717dc61866d7310c666649bbb0986
URL:    http://cgit.freedesktop.org/telepathy/telepathy-qt/commit/?id=6eafc3bf22b717dc61866d7310c666649bbb0986

Author: Daniele E. Domenichelli <daniele.domenichelli at gmail.com>
Date:   Wed Apr  4 20:36:22 2012 +0200

dbus-tubes: Fix warning and comment

---

 TelepathyQt/incoming-dbus-tube-channel.cpp |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/TelepathyQt/incoming-dbus-tube-channel.cpp b/TelepathyQt/incoming-dbus-tube-channel.cpp
index 5bd775b..79c505d 100644
--- a/TelepathyQt/incoming-dbus-tube-channel.cpp
+++ b/TelepathyQt/incoming-dbus-tube-channel.cpp
@@ -162,7 +162,7 @@ PendingDBusTubeConnection *IncomingDBusTubeChannel::acceptTube(bool allowOtherUs
 
     if (!isReady(DBusTubeChannel::FeatureCore)) {
         warning() << "DBusTubeChannel::FeatureCore must be ready before "
-            "calling offerTube";
+            "calling acceptTube";
         return new PendingDBusTubeConnection(QLatin1String(TP_QT_ERROR_NOT_AVAILABLE),
                 QLatin1String("Channel not ready"), IncomingDBusTubeChannelPtr(this));
     }
@@ -174,7 +174,7 @@ PendingDBusTubeConnection *IncomingDBusTubeChannel::acceptTube(bool allowOtherUs
                 QLatin1String("Channel busy"), IncomingDBusTubeChannelPtr(this));
     }
 
     // Let's offer the tube
     if (!allowOtherUsers && !supportsRestrictingToCurrentUser()) {
         warning() << "Current user restriction is not available for this tube, "
             "falling back to allowing any connection";
@@ -174,7 +174,7 @@ PendingDBusTubeConnection *IncomingDBusTubeChannel::acceptTube(bool allowOtherUs
     }
 
-    // Let's offer the tube
+    // Let's accept the tube
     if (!allowOtherUsers && !supportsRestrictingToCurrentUser()) {
         warning() << "Current user restriction is not available for this tube, "



More information about the telepathy-commits mailing list